* ---------------------------------------------------------------- ;
 * ---                       VERSION 4.5                        --- ;
 * ---------------------------------------------------------------- ;
 * The PATIENT SAFETY Indicator 17 (PSI-17) stand alone module of the AHRQ Quality
   Indicators software includes the following three programs, in
   addition to the programs CONTROL_PS17.SAS and PS17_PDFMTS.SAS:
        Program 1.   PS17_PDSAS1:  Assigns HCUP PEDIATRIC Quality
                       Indicators to inpatient records.
        Program P2.  PS17_PDSASP2:  Calculates observed provider rates
                       for Pediatric Quality Indicators.
        Program P3.  PS17_PDSASP3:  Calculates risk-adjusted provider rates
                       for Pediatric Quality Indicators.

******************************************************************* ;
****************************PLEASE READ**************************** ;
******************************************************************* ;
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software using your data are changes you make in this
   program (CONTROL_PSI17.SAS).  The modifications you make include such
   items as specifying the name and location of your input data
   set, the year of population data to be used, and the name and
   location of output data sets.
 
 * NOTE:  CONTROL_PS17.SAS is written so that you have the option to 
          read in data from and write out data to different 
          locations.  For example, "LIBNAME IN0" points to the 
          location or pathname of your input data set for program
          PDSAS1 and "LIBNAME OUT1" points to the location of the 
          output data set created by the PDSAS1 program.  These 
          locations can be different.  This pattern of allowing 
          you to specify the location of each input and output 
          data set is true for each of the different programs 
          referenced in CONTROL_PS17.SAS.  However, if you wish to read 
          in and write out all data to the same location you can.   
          The easiest way to do this is to make a global 
          change in CONTROL_PS17.SAS, changing "C:\PATHNAME" to the 
          location you wish to use.

 * NOTE:  In each of the six programs included with this
          package, as well as in the program which generates
          formats, there is a line of code that begins with
          "FILENAME CONTROL".  The USER MUST include after
          "FILENAME CONTROL" the location of the CONTROL_PS17.SAS file.

 * Generally speaking, a first-time user of this software would
   proceed as follows:
        1.  Modify CONTROL_PS17.SAS.  (MUST be done.)
        2.  In the program generating needed formats, i.e., in
            PS17_PDFMTS.SAS, specify location (path name) of
            CONTROL_PS17.SAS. (MUST be done.)
        3.  Run PS17_PDFMTS.SAS.  (MUST be done.)
        4.  In Program 1, i.e., in PS17_PDSAS1, specify location
            of CONTROL_PS17.SAS program.  (MUST be done.)
        5.  Run PS17_PDSAS1.  (MUST be done.)
        6.  If you want to generate provider-level Patient Safety Indicator 17 (PSI-17):
                a.  In Program P2, i.e., in PS17_PDSASP2, specify location
                    of CONTROL_PS17.SAS program.  (MUST be done if going to
                    run Program P2.)
                b.  Run PS17_PDSASP2.  (MUST have already run Program 1.)
        7.  If you want to generate risk-adjusted provider-level 
            Patient Safety Indicator 17(PSI-17):
                a.  In Program P3, i.e., in PS17_PDSASP3, specify location
                    of CONTROL_PS17.SAS program.  (MUST be done if going to
                    run Program P3.)
                b.  Run PS17_PDSASP3.  (MUST have already run Program 1 
                    and P2.)
        
 * ---------------------------------------------------------------- ;
 * ---                       All Programs                       --- ;
 * ---------------------------------------------------------------- ;
TITLE 'TITLE';                                  *<===USER may modify;
LIBNAME LIBRARY  "C:\PATHNAME";                 *<==USER MUST modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF COUNTY-LEVEL AREAS SHOULD BE CONVERTED TO MAs -- ;
 * ---     0 - County level with U.S. Census FIPS                -- ;
 * ---     1 - County level with Modified FIPS                   -- ;
 * ---     2 - Metro Area level with OMB 1999 definition         -- ;
 * ---     3 - Metro Area level with OMB 2003 definition         -- ;
 * ---------------------------------------------------------------- ;
%LET MALEVL = 0;                                *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * NOTE:  In program A2, the user should select                     ;
 *          the population data for the year that best              ;
 *          matches the discharge data.  Data are available for     ;
 *          1995 to 2013.                                           ;
 * ---------------------------------------------------------------- ;
%LET POPYEAR = 2011;                           *<===USER must modify;

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF POPULATION FILE -------------------------------- ;
 * ---------------------------------------------------------------- ;
FILENAME POPFILE  'C:\PATHNAME\pop95t13.txt'; *<===USER must modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED AT END OF EACH PGM --- ;
 * ---------------------------------------------------------------- ;
%LET PRINT = 0;                                 *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- COMMENT OUT TO CREATE AN UCOMPRESSED FILE                --- ;
 * ---------------------------------------------------------------- ;
OPTIONS COMPRESS=YES;


 * ---------------------------------------------------------------- ;
 * ---                         Program 1                        --- ;
 * ---------------------------------------------------------------- ;
LIBNAME IN0  "C:\PATHNAME";                     *<==USER MUST modify;
LIBNAME OUT1 "C:\PATHNAME";                     *<==USER MUST modify;

 * ---------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                             --- ;
 * ---------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                        --- ;
 * ---     30 DIAGNOSES (DX1-DX30)                              --- ;
 * ---     30 PROCEDURES (PR1-PR30)                             --- ;
 * ---------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSES, PROCEDURES AND RELATED       --- ;
 * --- VARIABLES TO MATCH INPUT DATA                            --- ;
 * ---------------------------------------------------------------- ;
%LET INFILE0  = SIDyy;                          *<==USER MUST modify;
%LET OUTFILE1 = PS17_PDI1;                     *<===USER may modify;
%LET NDX = 30;                                  *<===USER may modify;
%LET NPR = 30;                                  *<===USER may modify;
*%LET USEPOA = 1;                                *<===USER may modify;


 * ---------------------------------------------------------------- ;
 * - SET PRDAY TO 1 IF DATA AVAILABLE REGARDING NUMBER OF DAYS  --- ;
 * - FROM ADMISSION TO SECONDARY PROCEDURES                     --- ;
 * ---------------------------------------------------------------- ;
%LET PRDAY = 1;                                 *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL    --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE       --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER --- ;
 * - RUNNING PDSAS1.											--- ;
 * ---------------------------------------------------------------- ;
%LET DELFILE1  = PS17_DELETED;                   *<===USER may modify;

 * =================================================================;
 * ============PROVIDER-LEVEL PEDIATRIC QUALITY INDICATORS==========;
 * =================================================================;
 * ---                   Program P2-Observed Rates              --- ;
 * ---------------------------------------------------------------- ;
LIBNAME IN1 "C:\PATHNAME";                      *<==USER MUST modify;
LIBNAME OUTP2 "C:\PATHNAME";                    *<==USER MUST modify;

 * ----------------------------------------------------------------------- ;
 * --- TYPELVLP indicates the levels (or _TYPE_) of                    --- ;
 * --- summarization to be kept in the output.                         --- ;
 * ---                                                                 --- ;
 * ---  TYPELVLP      stratification                                   --- ;
 * ---  --------  ---------------------------------------------------- --- ;
 * ---     0      overall                                              --- ;
 * ---     1                                                      race --- ;
 * ---     2                                              payer        --- ;
 * ---     3                                              payer * race --- ;
 * ---     4                                        sex                --- ;
 * ---     5                                        sex         * race --- ;
 * ---     6                                        sex * payer        --- ;
 * ---     7                                        sex * payer * race --- ;
 * ---     8                                  age                      --- ;
 * ---     9                                  age               * race --- ;
 * ---    10                                  age       * payer        --- ;
 * ---    11                                  age       * payer * race --- ;
 * ---    12                                  age * sex                --- ;
 * ---    13                                  age * sex         * race --- ;
 * ---    14                                  age * sex * payer        --- ;
 * ---    15                                  age * sex * payer * race --- ;
 * ---    16                         ageday                            --- ;
 * ---    17                         ageday                     * race --- ;
 * ---    18                         ageday             * payer        --- ;
 * ---    19                         ageday             * payer * race --- ;
 * ---    20                         ageday       * sex                --- ;
 * ---    21                         ageday       * sex         * race --- ;
 * ---    22                         ageday       * sex * payer        --- ;
 * ---    23                         ageday       * sex * payer * race --- ;
 * ---    24                         ageday * age                      --- ;
 * ---    25                         ageday * age               * race --- ;
 * ---    26                         ageday * age       * payer        --- ;
 * ---    27                         ageday * age       * payer * race --- ;
 * ---    28                         ageday * age * sex                --- ;
 * ---    29                         ageday * age * sex         * race --- ;
 * ---    30                         ageday * age * sex * payer        --- ;
 * ---    31                         ageday * age * sex * payer * race --- ;
 * ---    32                  bwht                                     --- ;
 * ---    33                  bwht                              * race --- ;
 * ---    34                  bwht                      * payer        --- ;
 * ---    35                  bwht                      * payer * race --- ;
 * ---    36                  bwht                * sex                --- ;
 * ---    37                  bwht                * sex         * race --- ;
 * ---    38                  bwht                * sex * payer        --- ;
 * ---    39                  bwht                * sex * payer * race --- ;
 * ---    40                  bwht          * age                      --- ;
 * ---    41                  bwht          * age               * race --- ;
 * ---    42                  bwht          * age       * payer        --- ;
 * ---    43                  bwht          * age       * payer * race --- ;
 * ---    44                  bwht          * age * sex                --- ;
 * ---    45                  bwht          * age * sex         * race --- ;
 * ---    46                  bwht          * age * sex * payer        --- ;
 * ---    47                  bwht          * age * sex * payer * race --- ;
 * ---    48                  bwht * ageday                            --- ;
 * ---    49                  bwht * ageday                     * race --- ;
 * ---    50                  bwht * ageday             * payer        --- ;
 * ---    51                  bwht * ageday             * payer * race --- ;
 * ---    52                  bwht * ageday       * sex                --- ;
 * ---    53                  bwht * ageday       * sex         * race --- ;
 * ---    54                  bwht * ageday       * sex * payer        --- ;
 * ---    55                  bwht * ageday       * sex * payer * race --- ;
 * ---    56                  bwht * ageday * age                      --- ;
 * ---    57                  bwht * ageday * age               * race --- ;
 * ---    58                  bwht * ageday * age       * payer        --- ;
 * ---    59                  bwht * ageday * age       * payer * race --- ;
 * ---    60                  bwht * ageday * age * sex                --- ;
 * ---    61                  bwht * ageday * age * sex         * race --- ;
 * ---    62                  bwht * ageday * age * sex * payer        --- ;
 * ---    63                  bwht * ageday * age * sex * payer * race --- ;
 * ---    64       provider                                            --- ;
 * ---    65       provider                                     * race --- ;
 * ---    66       provider                             * payer        --- ;
 * ---    67       provider                             * payer * race --- ;
 * ---    68       provider                       * sex                --- ;
 * ---    69       provider                       * sex         * race --- ;
 * ---    70       provider                       * sex * payer        --- ;
 * ---    71       provider                       * sex * payer * race --- ;
 * ---    72       provider                 * age                      --- ;
 * ---    73       provider                 * age               * race --- ;
 * ---    74       provider                 * age       * payer        --- ;
 * ---    75       provider                 * age       * payer * race --- ;
 * ---    76       provider                 * age * sex                --- ;
 * ---    77       provider                 * age * sex         * race --- ;
 * ---    78       provider                 * age * sex * payer        --- ;
 * ---    79       provider                 * age * sex * payer * race --- ;
 * ---    80       provider        * ageday                            --- ;
 * ---    81       provider        * ageday                     * race --- ;
 * ---    82       provider        * ageday             * payer        --- ;
 * ---    83       provider        * ageday             * payer * race --- ;
 * ---    84       provider        * ageday       * sex                --- ;
 * ---    85       provider        * ageday       * sex         * race --- ;
 * ---    86       provider        * ageday       * sex * payer        --- ;
 * ---    87       provider        * ageday       * sex * payer * race --- ;
 * ---    88       provider        * ageday * age                      --- ;
 * ---    89       provider        * ageday * age               * race --- ;
 * ---    90       provider        * ageday * age       * payer        --- ;
 * ---    91       provider        * ageday * age       * payer * race --- ;
 * ---    92       provider        * ageday * age * sex                --- ;
 * ---    93       provider        * ageday * age * sex         * race --- ;
 * ---    94       provider        * ageday * age * sex * payer        --- ;
 * ---    95       provider        * ageday * age * sex * payer * race --- ;
 * ---    96       provider * bwht                                     --- ;
 * ---    97       provider * bwht                              * race --- ;
 * ---    98       provider * bwht                      * payer        --- ;
 * ---    99       provider * bwht                      * payer * race --- ;
 * ---   100       provider * bwht                * sex                --- ;
 * ---   101       provider * bwht                * sex         * race --- ;
 * ---   102       provider * bwht                * sex * payer        --- ;
 * ---   103       provider * bwht                * sex * payer * race --- ;
 * ---   104       provider * bwht          * age                      --- ;
 * ---   105       provider * bwht          * age               * race --- ;
 * ---   106       provider * bwht          * age       * payer        --- ;
 * ---   107       provider * bwht          * age       * payer * race --- ;
 * ---   108       provider * bwht          * age * sex                --- ;
 * ---   109       provider * bwht          * age * sex         * race --- ;
 * ---   110       provider * bwht          * age * sex * payer        --- ;
 * ---   111       provider * bwht          * age * sex * payer * race --- ;
 * ---   112       provider * bwht * ageday                            --- ;
 * ---   113       provider * bwht * ageday                     * race --- ;
 * ---   114       provider * bwht * ageday             * payer        --- ;
 * ---   115       provider * bwht * ageday             * payer * race --- ;
 * ---   116       provider * bwht * ageday       * sex                --- ;
 * ---   117       provider * bwht * ageday       * sex         * race --- ;
 * ---   118       provider * bwht * ageday       * sex * payer        --- ;
 * ---   119       provider * bwht * ageday       * sex * payer * race --- ;
 * ---   120       provider * bwht * ageday * age                      --- ;
 * ---   121       provider * bwht * ageday * age               * race --- ;
 * ---   122       provider * bwht * ageday * age       * payer        --- ;
 * ---   123       provider * bwht * ageday * age       * payer * race --- ;
 * ---   124       provider * bwht * ageday * age * sex                --- ;
 * ---   125       provider * bwht * ageday * age * sex         * race --- ;
 * ---   126       provider * bwht * ageday * age * sex * payer        --- ;
 * ---   127       provider * bwht * ageday * age * sex * payer * race --- ;
 * ---                                                                 --- ;
 * --- The default TYPELVLP (0,64) will provide an overall             --- :
 * --- and provider-level totals.                                      --- ;
 * ---                                                                 --- ;
 * ----------------------------------------------------------------------- ;
%LET TYPELVLP = IN (0,64);                      *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF MICRODATA INPUT (OUTPUT FROM PROGRAM 1) AND  --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED PROVIDER RATES.          --- ;
 * ---------------------------------------------------------------- ;
%LET INFILE1  = PS17_PDI1;                           *<===USER may modify;
%LET OUTFILP2 = PS17_PDP2;                           *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF WANT TO CREATE A COMMA-DELIMITED FILE FOR    --- ;
 * --- EXPORT INTO A SPREADSHEET.                               --- ;
 * ---------------------------------------------------------------- ;
%LET TEXTP2 = 0;                                *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION - ;
 * --- OF THE FILE.                                             --- ;
 * ---------------------------------------------------------------- ;
FILENAME PDTEXTP2 "C:\PATHNAME\PS17_PDTEXTP2.TXT";  *<===USER MUST modify;

 * ---------------------------------------------------------------- ;
 * ---       Program P3-Risk-Adjusted and Smoothed Rates       --- ;
 * ---------------------------------------------------------------- ;
LIBNAME INP2 "C:\PATHNAME";                     *<==USER MUST modify;
LIBNAME OUTP3 "C:\PATHNAME";                    *<==USER MUST modify;

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF PREDICTION SYNTAX FILE                         - ;
 * ---------------------------------------------------------------- ;
FILENAME PRDP 'C:\PATHNAME\PRDPDP45.TXT';      *<===USER MUST modify;

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF MSX STATISTICS FILE                            - ;
 * ---   FILE CONTAINS AN ARRAY OF SIGNAL VARIANCE AND            - ;
 * ---   POPULATION RATES                                         - ;
 * ---------------------------------------------------------------- ;
 * - SET TO MSXPDP45 FOR ADJUSTMENT WITH POA                      - ;
FILENAME MSXP "C:\PATHNAME\MSXPDP45.TXT";      *<===USER MUST modify;

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF INPUT RATES FILE (OUTPUT FROM PROGRAM P2) AND--- ;
 * --- PROVIDER LEVEL OUTPUT FILE.                              --- ;
 * ---------------------------------------------------------------- ;
%LET INFILEP2 = PS17_PDP2;                          *<===USER may modify;
%LET OUTFILP3 = PS17_PDP3;                          *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF WANT TO CREATE A COMMA-DELIMITED FILE FOR    --- ;
 * --- EXPORT INTO A SPREADSHEET.                               --- ;
 * ---------------------------------------------------------------- ;
%LET TEXTP3 = 0;                                *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION - ;
 * --- OF THE FILE.                                             --- ;
 * ---------------------------------------------------------------- ;
FILENAME PDTEXTP3 "C:\PATHNAME\PS17_PDTEXTP3.TXT";   *<===USER may modify;

