*==================================================================================================;
*  Title:  PROGRAM P3: CALCULATES RISK-ADJUSTED PROVIDER
*          RATES FOR AHRQ PATIENT SAFETY INDICATOR PSI-17 
*
*  Description:
*         CALCULATES RISK ADJUSTED RATES AND SMOOTHED RATES (MCMC NOT USED)   
*         THIS PSI INDICATOR ALSO INCLUDED IN PDI MODULE
*
*          >>>   VERSION 4.5, MAY 2013    <<<
*
*  USER NOTE: Version 4.5 AHRQ QI SAS software does not explicitly support the calculation 
*             of weighted estimates and standard errors using complex sampling designs.
*             The variable DISCWT (discharge weight) is set equal to 1 in the SAS1 program  
*             for this module, and consequently the variable does not weight any calculations   
*             in this program.If a DISCWT variable is present in the users dataset, 
*             all values are set to 1. 
*
*             In order to obtain weighted nationally representative estimates, additional 
*             calculations will need to be performed.  
*             For a more thorough description of weighted AHRQ QI analyses beginning with 
*             AHRQ QI SAS Version 4.1, see the technical documentation on the AHRQ QI website.
*===================================================================================================;

FILENAME CONTROL "C:\PATHNAME\CONTROL_PS17.SAS"; *<==USER MUST modify;

%INCLUDE CONTROL;

TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE RISK-ADJUSTED PROVIDER RATES';


 DATA &OUTFILP3.;
 SET INP2.&INFILEP2.(
    KEEP=HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT _TYPE_ 
         TPPS17 PPPS17 OPPS17);
 BY HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;

 %INCLUDE MSXP;

 ARRAY TRRY1{1} _TEMPORARY_ (13);
 ARRAY TRRY2{1}  OPPS17;
 ARRAY TRRY3{1}  PPPS17;
 ARRAY TRRY4{1}  EPPS17;
 ARRAY TRRY5{1}  RPPS17;
 ARRAY TRRY6{1}  SEPS17;
 ARRAY TRRY7{1}  VPPS17;
 ARRAY TRRY8{1}  SNPS17;
 ARRAY TRRY9{1}  SPPS17;
 ARRAY TRRY10{1} XPPS17;
 ARRAY TRRY11{1} LPPS17;
 ARRAY TRRY12{1} UPPS17;

 DO I = 1 TO 1;
    TRRY4(I) = ARRYP3(TRRY1(I));
    IF BWHTCAT = . AND AGEDCAT = . AND PAGECAT = . AND 
       SEXCAT = . AND PAYCAT = . AND RACECAT = . THEN DO;
       TRRY5(I)  = TRRY2(I);
       TRRY6(I)  = SQRT(TRRY2(I)*(1-TRRY2(I)) / TRRY3(I));
       TRRY7(I)  = TRRY6(I)**2;
       TRRY8(I)  = ARRYP2(TRRY1(I)) / (ARRYP2(TRRY1(I)) + TRRY7(I));
       TRRY9(I)  = (TRRY5(I) * TRRY8(I)) + ((1 -  TRRY8(I)) * ARRYP3(TRRY1(I)));
       TRRY10(I)  = SQRT(ARRYP2(TRRY1(I))- (TRRY8(I) * ARRYP2(TRRY1(I))));
    END;
    ELSE DO;
       TRRY5(I)  = (TRRY2(I) / TRRY4(I));
       TRRY6(I)  = SQRT(TRRY2(I)*(1-TRRY2(I)) / TRRY3(I)) / TRRY4(I);
       TRRY7(I)  = .;
       TRRY9(I)  = .;
       TRRY10(I)  = .;
    END;
    TRRY11(I)   = TRRY5(I) - (1.96 * TRRY6(I));
    IF TRRY11(I) < 0 THEN TRRY11(I) = 0;
    TRRY12(I)   = TRRY5(I) + (1.96 * TRRY6(I));
 END;

 LABEL
 EPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Expected)'
 ;

 LABEL
 RPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Risk Adj)'
 ;

 LABEL
 LPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Lower CL)'
 ;

 LABEL
 UPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Upper CL)'
 ;

 LABEL
 SPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Smoothed)'
 ;

 LABEL
 XPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Smthe SE)'
 ;

 LABEL
 VPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Variance)'
 ;

 ARRAY ARRY1{1} EPPS17;
 ARRAY ARRY2{1} RPPS17;
 ARRAY ARRY3{1} LPPS17;
 ARRAY ARRY4{1} UPPS17;
 ARRAY ARRY5{1} SPPS17;
 ARRAY ARRY6{1} XPPS17;
 ARRAY ARRY7{1} VPPS17;
 ARRAY ARRY8{1} PPPS17;

 DO I = 1 TO 1;
    IF ARRY8(I) <= 2 THEN DO;
       ARRY1(I) = .; ARRY2(I) = .; ARRY3(I) = .; ARRY4(I) = .;
       ARRY5(I) = .; ARRY6(I) = .; ARRY7(I) = .; 
    END;
 END;

 DROP I;

 FORMAT EPPS17
     	LPPS17
		OPPS17
		RPPS17
		SEPS17
		SNPS17 
		SPPS17
		UPPS17
		VPPS17
		XPPS17 13.7
		TPPS17
		PPPS17 13.0;
 RUN;

 /***--------------------------------------------------------------------------------------------------------------------
    Provider-level indicators: PSI # 17 (linked mother-infant records) are not risk adjusted in the software because 
    the available data does not include the necessary covariates.   For these indicators, the observed rate is the 
    applicable measure of performance, and the expected, risk-adjusted, and smoothed rates provide no additional 
    information. Starting in version 4.5, the values for those rates will be set to be missing.
 ---------------------------------------------------------------------------------------------------------------------***/

 DATA OUTP3.&OUTFILP3.;
   SET &OUTFILP3.;
        EPPS17 =.;
     	LPPS17 =.;
		RPPS17 =.;
		SEPS17 =.;
		SNPS17 =.; 
		SPPS17 =.;
		UPPS17 =.;
		VPPS17 =.;
		XPPS17 =.;
 RUN;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER-LEVEL MERGED FILE --------- ;
 * -------------------------------------------------------------- ;

 PROC CONTENTS DATA=OUTP3.&OUTFILP3. POSITION;
 RUN;

 PROC MEANS DATA=OUTP3.&OUTFILP3.
   (WHERE=(_TYPE_ IN (64))) N NMISS MIN MAX MEAN SUM NOLABELS;
 TITLE4 "SUMMARY OF PROVIDER-LEVEL RATES (_TYPE_=64)";
 RUN;

 * -------------------------------------------------------------- ;
 * --- PRINT PROVIDER MERGED FILE ------------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT,CASE);

 PROC PRINT DATA=OUTP3.&OUTFILP3. LABEL SPLIT="*";
 %IF &CASE. = 2 %THEN %DO;
 VAR HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT 
     TP&PD.;
 LABEL HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD. = "TP&PD.*(Volume)"
 ;
 FORMAT BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. 13.0;
 %END;
 %ELSE %IF &CASE. = 1 %THEN %DO;
 VAR HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT
     TP&PD. PP&PD. OP&PD.;
 LABEL HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD. = "TP&PD.*(Numerator)"
       PP&PD. = "PP&PD.*(Denominator)"
       OP&PD. = "OP&PD.*(Observed)"
 ;
 FORMAT BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. PP&PD. 13.0 OP&PD. 8.6;
 %END;
 %ELSE %DO;
 VAR HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT
     TP&PD. PP&PD. OP&PD. EP&PD. RP&PD. LP&PD. UP&PD. SP&PD. XP&PD.;
 LABEL HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD. = "TP&PD.*(Numerator)"
       PP&PD. = "PP&PD.*(Denominator)"
       OP&PD. = "OP&PD.*(Observed)"
       EP&PD. = "EP&PD.*(Expected)"
       RP&PD. = "RP&PD.*(Risk Adj)"
       LP&PD. = "LP&PD.*(Lower CL)"
       UP&PD. = "UP&PD.*(Upper CL)"
       SP&PD. = "SP&PD.*(Smoothed)"
       XP&PD. = "XP&PD.*(Smoth SE)"
 ;
 FORMAT BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. PP&PD. 13.0 OP&PD. RP&PD. SP&PD. EP&PD. 8.6;
 %END;
 TITLE4 "FINAL OUTPUT";
 TITLE5 "Indicator # &PD.: &TEXT";

 RUN;

 %MEND PRT;

 %PRT(PS17,Birth Trauma Rate - Injury to Neonate,0);

 %END;

 %MEND PRT2;

 %PRT2;

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TEXTP3. = 1  %THEN %DO;

 DATA _NULL_;
 SET OUTP3.&OUTFILP3;
 FILE PDTEXTP3 LRECL=4000;
 IF _N_=1 THEN PUT
 "Hosp Id" "," "BWht" "," "AgeD" "," "Age"  "," 
 "Sex" "," "Payer" "," "Race"  "," "Type" ","
 "TPPS17" ","
 "PPPS17" ","
 "OPPS17" ","
 "EPPS17" ","
 "RPPS17" ","
 "LPPS17" ","
 "UPPS17" ","
 "SPPS17" ","
 "XPPS17"
 ;
 PUT HOSPID 13. "," BWHTCAT 3. "," AGEDCAT 3. "," PAGECAT 3. "," 
     SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2. ","
 (TPPS17) (7.0 ",") "," 
 (PPPS17) (13.2 ",") ","
 (OPPS17) (12.10 ",") ","
 (EPPS17) (12.10 ",") ","
 (RPPS17) (12.10 ",") ","
 (LPPS17) (12.10 ",") ","
 (UPPS17) (12.10 ",") ","
 (SPPS17) (12.10 ",") ","
 (XPPS17) (12.10 ",");

 RUN;

 %END;

 %MEND TEXT;

 %TEXT;
